@@ -1,6 +1,8 @@
 import os, argparse
 import tornado.ioloop
 import tornado.web
+from jupyterhub.utils import url_path_join
+from jupyterhub.services.auth import HubOAuthCallbackHandler
 from .service import SwanNotificationsService
 
 
@@ -16,7 +18,11 @@ def main():
 
     prefix = os.environ.get('JUPYTERHUB_SERVICE_PREFIX', args.prefix)
 
-    app = tornado.web.Application([(prefix, SwanNotificationsService, 
-                    {'notifications_file': args.notification, 'maintenance_file': args.maintenance})])
+    app = tornado.web.Application([
+            (prefix, SwanNotificationsService,
+                {'notifications_file': args.notification, 'maintenance_file': args.maintenance}),
+            (url_path_join(prefix,"oauth_callback"),HubOAuthCallbackHandler),
+            ],
+            cookie_secret=os.urandom(32))
     app.listen(args.port)
-    tornado.ioloop.IOLoop.current().start()
\ No newline at end of file
+    tornado.ioloop.IOLoop.current().start()
